@@ -14,6 +14,7 @@ use PHPUnit\Framework\Attributes\DataProvider;
 use PHPUnit\Framework\Attributes\Group;
 use PHPUnit\Framework\Attributes\Small;
 use PHPUnit\Framework\TestCase;
+use PHPUnit\TestFixture\RequirementsEnvironmentVariableTest;
 
 #[CoversClass(Requirements::class)]
 #[Small]
@@ -130,6 +131,11 @@ final class RequirementsTest extends TestCase
         ];
     }
 
+    protected function tearDown(): void
+    {
+        unset($_ENV['FOO'], $_ENV['BAR']);
+    }
+
     #[DataProvider('missingRequirementsProvider')]
     public function testGetMissingRequirements(string $test, array $result): void
     {
@@ -138,4 +144,19 @@ final class RequirementsTest extends TestCase
             (new Requirements)->requirementsNotSatisfiedFor(\PHPUnit\TestFixture\RequirementsTest::class, $test),
         );
     }
+
+    public function testGetMissingEnvironmentVariableRequirements(): void
+    {
+        $_ENV['FOO'] = 'foo';
+        $_ENV['BAR'] = '';
+
+        $this->assertEquals(
+            [
+                'Environment variable "FOO" is required to be "bar".',
+                'Environment variable "BAR" is required.',
+                'Environment variable "BAZ" is required.',
+            ],
+            (new Requirements)->requirementsNotSatisfiedFor(RequirementsEnvironmentVariableTest::class, 'testRequiresEnvironmentVariable'),
+        );
+    }
 }
